import 'package:flutter_test/flutter_test.dart';
import 'package:rec_api_dart/src/api_path.dart';

void main() {
  test('ApiPath works with basic path', () async {
    final testPath = ApiPath('/test/path');

    expect(testPath.path, '/test/path');
    expect(testPath.queryParams, null);
    expect(testPath.asUri('my-org.com').toString(), 'https://my-org.com/test/path');
  });

  test('ApiPath.withQueryParams sets params', () async {
    final testPath = ApiPath('/test/path').withQueryParams({'test': '1234'});

    expect(testPath.path, '/test/path');
    expect(testPath.queryParams, {'test': '1234'});
    expect(testPath.asUri('my-org.com').toString(), 'https://my-org.com/test/path?test=1234');
  });

  test('ApiPath.withQueryParams returns new instance', () async {
    final testPath = ApiPath('/test/path');
    final testPathWithParams = testPath.withQueryParams({'test': '1234'});

    expect(testPath != testPathWithParams, true);
  });

  test('ApiPath.withParams interpolates params', () async {
    final testPath = ApiPath('/test/path/{{test}}');
    final testPathWithParams = testPath.withParams({'test': '1234'});

    expect(testPathWithParams.path, '/test/path/1234');
  });

  test('ApiPath.append appends correctly', () async {
    final testPath = ApiPath('/test/path').append('other-path');

    expect(testPath.path, '/test/path/other-path');
  });

  test('ApiPath.appendMultiple appends correctly', () async {
    final testPath = ApiPath('/test/path').appendMultiple(['other-path', 'bob']);

    expect(testPath.path, '/test/path/other-path/bob');
  });
}
