import 'package:flutter_test/flutter_test.dart';
import 'package:rec_api_dart/src/entities/transactions/currency.ent.dart';

void main() {
  test('Currency.find works for eur and rec', () async {
    final rec = Currency.find(CurrencyNames.REC);
    final eur = Currency.find(CurrencyNames.EUR);

    expect(rec.name, CurrencyNames.REC);
    expect(eur.name, CurrencyNames.EUR);
  });

  test('Currency::scale works for eur and rec', () async {
    final rec = Currency.find(CurrencyNames.REC);
    final eur = Currency.find(CurrencyNames.EUR);

    expect(rec.scaleAmount(100000000), 1);
    expect(eur.scaleAmount(100), 1);
  });

  test('Currency::toJson works for eur and rec', () async {
    final rec = Currency.find(CurrencyNames.REC);
    final eur = Currency.find(CurrencyNames.EUR);

    expect(rec.toJson(), {
      'name': rec.name,
      'symbol': rec.symbol,
      'scale': rec.scale,
      'decimals': rec.decimals,
    });
    expect(eur.toJson(), {
      'name': eur.name,
      'symbol': eur.symbol,
      'scale': eur.scale,
      'decimals': eur.decimals,
    });
  });

  test('Currency.scale works for eur', () async {
    expect(
      Currency.format(100, decimals: 2, locale: 'es_ES'),
      '100,00',
    );

    expect(
      Currency.format(100, decimals: 2, locale: 'en_UK'),
      '100.00',
    );
  });
}
